@@ -40,7 +40,7 @@ func IppService(log *LogMessage, services *DNSSdServices,
 
 	// Query printer attributes
 	uri := fmt.Sprintf("http://localhost:%d/ipp/print", port)
-	msg, err := ippGetPrinterAttributes(log, c, uri)
+	msg, err := ippGetPrinterAttributes(log, c, quirks, uri)
 	if err != nil {
 		return
 	}
@@ -61,7 +61,7 @@ func IppService(log *LogMessage, services *DNSSdServices,
 		// for now, just in case. Firmwares in general are
 		// too buggy, I can't trust them :-(
 		uri = fmt.Sprintf("http://localhost:%d/ipp/faxout", port)
-		if _, err2 := ippGetPrinterAttributes(log, c, uri); err2 == nil {
+		if _, err2 := ippGetPrinterAttributes(log, c, quirks, uri); err2 == nil {
 			canFax = true
 			log.Debug(' ', "IPP FaxOut service detected")
 		} else {
@@ -105,8 +105,8 @@ func IppService(log *LogMessage, services *DNSSdServices,
 //   3) It is not an IPP error response
 //
 // Otherwise, the appropriate error is generated and returned
-func ippGetPrinterAttributes(log *LogMessage, c *http.Client, uri string) (
-	msg *goipp.Message, err error) {
+func ippGetPrinterAttributes(log *LogMessage, c *http.Client,
+	quirks QuirksSet, uri string) (msg *goipp.Message, err error) {
 
 	// Query printer attributes
 	msg = goipp.NewRequest(goipp.DefaultVersion, goipp.OpGetPrinterAttributes, 1)
@@ -118,21 +118,27 @@ func ippGetPrinterAttributes(log *LogMessage, c *http.Client, uri string) (
 		goipp.TagURI, goipp.String(uri)))
 
 	rq := goipp.Attribute{Name: "requested-attributes"}
-	rq.Values.Add(goipp.TagKeyword, goipp.String("color-supported"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("document-format-supported"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("media-size-supported"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("mopria-certified"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-device-id"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-dns-sd-name"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-icons"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-info"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-kind"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-location"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-make-and-model"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-more-info"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-uuid"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("sides-supported"))
-	rq.Values.Add(goipp.TagKeyword, goipp.String("urf-supported"))
+
+	if Conf.LogAllPrinterAttrs {
+		rq.Values.Add(goipp.TagKeyword, goipp.String("all"))
+	} else {
+		rq.Values.Add(goipp.TagKeyword, goipp.String("color-supported"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("document-format-supported"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("media-size-supported"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("mopria-certified"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-device-id"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-dns-sd-name"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-icons"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-info"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-kind"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-location"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-make-and-model"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-more-info"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("printer-uuid"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("sides-supported"))
+		rq.Values.Add(goipp.TagKeyword, goipp.String("urf-supported"))
+	}
+
 	msg.Operation.Add(rq)
 
 	log.Add(LogTraceIPP, '>', "IPP request:").
@@ -162,7 +168,9 @@ func ippGetPrinterAttributes(log *LogMessage, c *http.Client, uri string) (
 		return
 	}
 
-	err = msg.DecodeBytes(respData)
+	err = msg.DecodeBytesEx(respData,
+		goipp.DecoderOptions{EnableWorkarounds: true})
+
 	if err != nil {
 		log.Debug(' ', "Failed to decode IPP message: %s", err)
 		log.HexDump(LogTraceIPP, ' ', respData)
@@ -176,7 +184,7 @@ func ippGetPrinterAttributes(log *LogMessage, c *http.Client, uri string) (
 		Flush()
 
 	// Check response status
-	if msg.Code >= 100 {
+	if msg.Code >= 0x100 && !quirks.GetIgnoreIppStatus() {
 		err = fmt.Errorf("IPP: %s", goipp.Status(msg.Code))
 		return
 	}
@@ -352,53 +360,53 @@ func (attrs ippAttrs) getPaperMax() string {
 		return ""
 	}
 
-	var x_dim_max, y_dim_max int
+	var xDimMax, yDimMax int
 
 	for _, collection := range vals {
-		var x_dim_attr, y_dim_attr goipp.Attribute
+		var xDimAttr, yDimAttr goipp.Attribute
 		attrs := collection.(goipp.Collection)
 		for i := len(attrs) - 1; i >= 0; i-- {
 			switch attrs[i].Name {
 			case "x-dimension":
-				x_dim_attr = attrs[i]
+				xDimAttr = attrs[i]
 			case "y-dimension":
-				y_dim_attr = attrs[i]
+				yDimAttr = attrs[i]
 			}
 		}
 
-		if len(x_dim_attr.Values) > 0 {
-			switch dim := x_dim_attr.Values[0].V.(type) {
+		if len(xDimAttr.Values) > 0 {
+			switch dim := xDimAttr.Values[0].V.(type) {
 			case goipp.Integer:
-				if int(dim) > x_dim_max {
-					x_dim_max = int(dim)
+				if int(dim) > xDimMax {
+					xDimMax = int(dim)
 				}
 			case goipp.Range:
-				if int(dim.Upper) > x_dim_max {
-					x_dim_max = int(dim.Upper)
+				if int(dim.Upper) > xDimMax {
+					xDimMax = int(dim.Upper)
 				}
 			}
 		}
 
-		if len(y_dim_attr.Values) > 0 {
-			switch dim := y_dim_attr.Values[0].V.(type) {
+		if len(yDimAttr.Values) > 0 {
+			switch dim := yDimAttr.Values[0].V.(type) {
 			case goipp.Integer:
-				if int(dim) > y_dim_max {
-					y_dim_max = int(dim)
+				if int(dim) > yDimMax {
+					yDimMax = int(dim)
 				}
 			case goipp.Range:
-				if int(dim.Upper) > y_dim_max {
-					y_dim_max = int(dim.Upper)
+				if int(dim.Upper) > yDimMax {
+					yDimMax = int(dim.Upper)
 				}
 			}
 		}
 	}
 
-	if x_dim_max == 0 || y_dim_max == 0 {
+	if xDimMax == 0 || yDimMax == 0 {
 		return ""
 	}
 
 	// Now classify by paper size
-	return PaperSize{x_dim_max, y_dim_max}.Classify()
+	return PaperSize{xDimMax, yDimMax}.Classify()
 }
 
 // Get a single-string attribute.
