@@ -27,6 +27,9 @@ const (
 	// PathLockFile defines path to lock file
 	PathLockFile = PathLockDir + "/ipp-usb.lock"
 
+	// PathControlSocket defines path to the control socket
+	PathControlSocket = PathProgState + "/ctrl"
+
 	// PathProgStateDev defines path to directory where per-device state
 	// files are saved to
 	PathProgStateDev = PathProgState + "/dev"
