@@ -153,19 +153,36 @@ func (desc UsbDeviceDesc) GetUsbDeviceInfo() (UsbDeviceInfo, error) {
 
 // UsbIfDesc represents an USB interface descriptor
 type UsbIfDesc struct {
-	Config   int // Configuration
-	IfNum    int // Interface number
-	Alt      int // Alternate setting
-	Class    int // Class
-	SubClass int // Subclass
-	Proto    int // Protocol
+	Vendor   uint16 // USB Vendor ID
+	Product  uint16 // USB Device ID
+	Config   int    // Configuration
+	IfNum    int    // Interface number
+	Alt      int    // Alternate setting
+	Class    int    // Class
+	SubClass int    // Subclass
+	Proto    int    // Protocol
 }
 
-// UsbIfDesc check if interface is IPP over USB
+// IsIppOverUsb check if interface is IPP over USB
+//
+// FIXME. The matching rules must be configurable
 func (ifdesc UsbIfDesc) IsIppOverUsb() bool {
-	return ifdesc.Class == 7 &&
-		ifdesc.SubClass == 1 &&
-		ifdesc.Proto == 4
+	switch {
+	// The classical combination, 7/1/4
+	case ifdesc.Class == 7 && ifdesc.SubClass == 1 && ifdesc.Proto == 4:
+		return true
+
+	// Some HP devices use non-standard combination, 255/9/1
+	//
+	// This is valid at least with the following devices:
+	//   HP LaserJet MFP M426fdn
+	//   HP ColorLaserJet MFP M278-M281
+	case ifdesc.Vendor == 0x03f0 &&
+		ifdesc.Class == 255 && ifdesc.SubClass == 9 && ifdesc.Proto == 1:
+		return true
+	}
+
+	return false
 }
 
 // UsbDeviceInfo represents USB device information
@@ -219,7 +236,7 @@ func (caps UsbIppBasicCaps) String() string {
 	return strings.Join(s, ",")
 }
 
-// Fix up precomputed fields
+// FixUp fixes up precomputed fields
 func (info *UsbDeviceInfo) FixUp() {
 	mfg := strings.TrimSpace(info.Manufacturer)
 	prod := strings.TrimSpace(info.ProductName)
