@@ -52,7 +52,7 @@ func NewUsbTransport(desc UsbDeviceDesc) (*UsbTransport, error) {
 		addr:         desc.UsbAddr,
 		log:          NewLogger(),
 		dev:          dev,
-		connReleased: make(chan struct{}),
+		connReleased: make(chan struct{}, 1),
 		shutdown:     make(chan struct{}),
 	}
 
@@ -95,7 +95,9 @@ func NewUsbTransport(desc UsbDeviceDesc) (*UsbTransport, error) {
 		if quirks.ResetMethod != QuirksResetUnset {
 			log.Debug(' ', "    init-reset = %s", quirks.ResetMethod)
 		}
-		for name, value := range quirks.HttpHeaders {
+		log.Debug(' ', "    ignore-ipp-status= %v", quirks.IgnoreIppStatus)
+
+		for name, value := range quirks.HTTPHeaders {
 			log.Debug(' ', "    http-%s = %q", strings.ToLower(name), value)
 		}
 	}
@@ -367,7 +369,7 @@ func (transport *UsbTransport) RoundTripWithSession(session int,
 
 	// Apply quirks
 	for _, quirks := range transport.quirks {
-		for name, value := range quirks.HttpHeaders {
+		for name, value := range quirks.HTTPHeaders {
 			if value != "" {
 				outreq.Header.Set(name, value)
 			} else {
@@ -399,6 +401,8 @@ func (transport *UsbTransport) RoundTripWithSession(session int,
 	switch {
 	case outreq.ContentLength <= 0:
 		// Nothing to do
+		transport.log.HTTPDebug('>', session,
+			"body is chunked, sending as is")
 
 	case outreq.ContentLength < 16384:
 		// Body is small, prefetch it before sending to USB
